==> knative-model-4.8.0-sources.jar: annotations/io/fabric8/knative/serving/v1/RevisionTemplateSpecFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface RevisionTemplateSpecFluent<A extends RevisionTemplateSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public RevisionTemplateSpecFluent.MetadataNested<A> editMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public RevisionSpec getSpec();
    public RevisionSpec buildSpec();
    public A withSpec(RevisionSpec spec);
    public Boolean hasSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpecLike(RevisionSpec item);
    public RevisionTemplateSpecFluent.SpecNested<A> editSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(RevisionSpec item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<RevisionTemplateSpecFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RevisionSpecFluent<RevisionTemplateSpecFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}

==> knative-model-4.10.1-sources.jar: annotations/io/fabric8/knative/serving/v1/RevisionTemplateSpecFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface RevisionTemplateSpecFluent<A extends RevisionTemplateSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public RevisionTemplateSpecFluent.MetadataNested<A> editMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadata();
    public RevisionTemplateSpecFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public RevisionSpec getSpec();
    public RevisionSpec buildSpec();
    public A withSpec(RevisionSpec spec);
    public Boolean hasSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> withNewSpecLike(RevisionSpec item);
    public RevisionTemplateSpecFluent.SpecNested<A> editSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpec();
    public RevisionTemplateSpecFluent.SpecNested<A> editOrNewSpecLike(RevisionSpec item);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<RevisionTemplateSpecFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RevisionSpecFluent<RevisionTemplateSpecFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}


}
